Balloon

Struct Balloon 

pub struct Balloon<'key, D: Digest + FixedOutputReset>{
    pub digest: PhantomData<D>,
    pub algorithm: Algorithm,
    pub params: Params,
    pub secret: Option<&'key [u8]>,
}
Balloon context.

This is the primary type of this crate’s API, and contains the following:

  • Default set of Params to be used
  • (Optional) Secret key a.k.a. “pepper” to be used

Fields

digest: PhantomData<D>

Storing which hash function is used

algorithm: Algorithm

Algorithm to use

params: Params

Algorithm parameters

secret: Option<&'key [u8]>

Key array

Implementations

Source

impl<'key, D: Digest + FixedOutputReset> Balloon<'key, D>

pub fn new( algorithm: Algorithm, params: Params, secret: Option<&'key [u8]>, ) -> Self

Create a new Balloon context.

pub fn hash( &self, pwd: &[u8], salt: &[u8], ) -> Result<GenericArray<u8, D::OutputSize>>

Available on crate feature alloc only.

Hash a password and associated parameters.

pub fn hash_into( &self, pwd: &[u8], salt: &[u8], output: &mut [u8], ) -> Result<()>

Available on crate feature alloc only.

Hash a password and associated parameters.

The output has to have the same size as the hash output size: D::OutputSize.

pub fn hash_with_memory( &self, pwd: &[u8], salt: &[u8], memory_blocks: &mut [GenericArray<u8, D::OutputSize>], ) -> Result<GenericArray<u8, D::OutputSize>>

Hash a password and associated parameters.

This method takes an explicit memory_blocks parameter which allows the caller to provide the backing storage for the algorithm’s state:

  • Users with the alloc feature enabled can use Balloon::hash to have it allocated for them.
  • no_std users on “heapless” targets can use an array of the GenericArray type to stack allocate this buffer. It needs a minimum size of s_cost or s_cost * p_cost with the parallel crate feature enabled.
pub fn hash_into_with_memory( &self, pwd: &[u8], salt: &[u8], memory_blocks: &mut [GenericArray<u8, D::OutputSize>], output: &mut [u8], ) -> Result<()>

Hash a password and associated parameters into the provided output buffer.

The output has to have the same size as the hash output size: D::OutputSize.

See Balloon::hash_with_memory for more details.