pub struct Balloon<'key, D: Digest + FixedOutputReset>{
pub digest: PhantomData<D>,
pub algorithm: Algorithm,
pub params: Params,
pub secret: Option<&'key [u8]>,
}Expand description
Balloon context.
This is the primary type of this crate’s API, and contains the following:
- Default set of
Paramsto be used - (Optional) Secret key a.k.a. “pepper” to be used
Fields
digest: PhantomData<D>Storing which hash function is used
algorithm: AlgorithmAlgorithm to use
params: ParamsAlgorithm parameters
secret: Option<&'key [u8]>Key array
Implementations
Sourceimpl<'key, D: Digest + FixedOutputReset> Balloon<'key, D>
impl<'key, D: Digest + FixedOutputReset> Balloon<'key, D>
Sourcepub fn new(
algorithm: Algorithm,
params: Params,
secret: Option<&'key [u8]>,
) -> Self
pub fn new( algorithm: Algorithm, params: Params, secret: Option<&'key [u8]>, ) -> Self
Create a new Balloon context.
Sourcepub fn hash(
&self,
pwd: &[u8],
salt: &[u8],
) -> Result<GenericArray<u8, D::OutputSize>>
Available on crate feature alloc only.
pub fn hash( &self, pwd: &[u8], salt: &[u8], ) -> Result<GenericArray<u8, D::OutputSize>>
alloc only.Hash a password and associated parameters.
Sourcepub fn hash_into(
&self,
pwd: &[u8],
salt: &[u8],
output: &mut [u8],
) -> Result<()>
Available on crate feature alloc only.
pub fn hash_into( &self, pwd: &[u8], salt: &[u8], output: &mut [u8], ) -> Result<()>
alloc only.Hash a password and associated parameters.
The output has to have the same size as the hash output size: D::OutputSize.
Sourcepub fn hash_with_memory(
&self,
pwd: &[u8],
salt: &[u8],
memory_blocks: &mut [GenericArray<u8, D::OutputSize>],
) -> Result<GenericArray<u8, D::OutputSize>>
pub fn hash_with_memory( &self, pwd: &[u8], salt: &[u8], memory_blocks: &mut [GenericArray<u8, D::OutputSize>], ) -> Result<GenericArray<u8, D::OutputSize>>
Hash a password and associated parameters.
This method takes an explicit memory_blocks parameter which allows
the caller to provide the backing storage for the algorithm’s state:
- Users with the
allocfeature enabled can useBalloon::hashto have it allocated for them. no_stdusers on “heapless” targets can use an array of theGenericArraytype to stack allocate this buffer. It needs a minimum size ofs_costors_cost * p_costwith theparallelcrate feature enabled.
Sourcepub fn hash_into_with_memory(
&self,
pwd: &[u8],
salt: &[u8],
memory_blocks: &mut [GenericArray<u8, D::OutputSize>],
output: &mut [u8],
) -> Result<()>
pub fn hash_into_with_memory( &self, pwd: &[u8], salt: &[u8], memory_blocks: &mut [GenericArray<u8, D::OutputSize>], output: &mut [u8], ) -> Result<()>
Hash a password and associated parameters into the provided output buffer.
The output has to have the same size as the hash output size: D::OutputSize.
See Balloon::hash_with_memory for more details.